
import { Modal, Button, message, } from 'antd';
import React, { useState, useRef } from 'react';
import { PageContainer, FooterToolbar } from '@ant-design/pro-layout';
import { PlusOutlined } from '@ant-design/icons';
import ProTable from '@ant-design/pro-table';
import CreateForm from './components/CreateForm';
import { GetFoodMenuInfoPage, UpdateFoodMenu, AddFoodMenu, DelFoodMenu, } from "./services";
import MenuGoods from './components/MenuGoods';

const key = 'message';

//添加
const handleAdd = async (fields) => {
	let result = false;
	try {
		message.loading('正在添加', key);
		await AddFoodMenu(JSON.stringify(fields)).then((r) => {
			message.destroy(key);
			if (r.data) {
				message.success('添加成功');
				result = true;
			} else {
				message.error(r.errors || '添加失败');
				result = false;
			}
		});
	} catch (error) {
		message.error('添加失败请重试！');
		result = false;
	}
	return result;
};


//修改
const handleUpdate = async (fields) => {
	let result = false;
	try {
		message.loading('正在修改', key);
		message.destroy(key);
		await UpdateFoodMenu(JSON.stringify(fields)).then((r) => {
			message.destroy(key);
			if (r.data) {
				message.success('修改成功',);
				result = true;
			} else {
				message.error(r.errors || '修改失败');
				result = false;
			}
		});
	} catch (error) {
		message.error('修改失败请重试！');
		result = false;
	}
	return result;
};


//删除
const handleRemove = async (selectedRows) => {
	try {
		message.loading('正在删除');
		let ids = [];
		selectedRows.forEach((item) => {
			ids.push(item.id);
		});
		await DelFoodMenu(ids).then((r) => {
			message.destroy();
			if (r.data) {
				message.success('删除成功');
				return true;
			} else {
				message.error('菜谱已关联到商品，删除失败');
				return false;
			}
		});
	} catch (error) {
		message.error('删除失败请重试！');
		return false;
	}
};

const GoodsTypeManage = () => {
	const [createModalVisible, handleModalVisible] = useState(false);
	const actionRef = useRef();
	const [currentRow, setCurrentRow] = useState();
	const [selectedRowsState, setSelectedRows] = useState([]);
	// 是否展示 关联加盟商商品 弹窗
	const [menuGoodsModal, setMenuGoodsModal] = useState(false);
	const columns = [
		{
			title: '主键',
			dataIndex: 'id',
			hideInSearch: true,
			hideInTable: true,
			tip: '规则名称是唯一的 key'
		},
		{
			title: '菜谱名称',
			dataIndex: 'name',
		},
		{
			title: '菜谱编码',
			dataIndex: 'code',
		},
		{
			title: '排序',
			dataIndex: 'sort',
		},
		{
			title: '操作',
			dataIndex: 'option',
			valueType: 'option',
			render: (_, record) => [
				<a
					key="config"
					onClick={() => {
						handleModalVisible(true);
						setCurrentRow(record);
					}} >
					编辑
				</a>,
				<a key="food" onClick={() => {
					setCurrentRow(record);
					setMenuGoodsModal(true);
				}}>
					关联加盟商商品
				</a>
			],
		},
	];

	/**
	 * 关联加盟商商品成功 回调函数
	 */
	const handleMenuGoodsOk = () => {
		setMenuGoodsModal(false);
	}

	return (
		<PageContainer>
			<ProTable
				headerTitle="菜谱基础信息"
				actionRef={actionRef}
				rowKey="id"
				search={{
					labelWidth: 120,
				}}
				toolBarRender={() => [
					<Button
						type="primary"
						key="primary"
						onClick={() => {
							handleModalVisible(true);
						}} >
						<PlusOutlined /> 新建
					</Button>,
				]}
				request={async (params) => {
					var data = [];
					var total = 0;
					await GetFoodMenuInfoPage(params).then((r) => {
						data = r.data.data;
						total = r.data.total;
					});
					return {
						data: data,
						success: true,
						total: total,
					};
				}}
				columns={columns}
				rowSelection={{
					onChange: (_, selectedRows) => {
						setSelectedRows(selectedRows);
					},
				}}
			/>
			{selectedRowsState?.length > 0 && (
				<FooterToolbar
					extra={
						<div>
							已选择{' '}
							<a
								style={{
									fontWeight: 600,
								}}
							>
								{selectedRowsState.length}
							</a>{' '}
							项 &nbsp;&nbsp;
						</div>
					}
				>
					<Button
						onClick={async () => {
							await handleRemove(selectedRowsState);
							setSelectedRows([]);
							actionRef.current?.reloadAndRest?.();
						}}
					>
						删除
					</Button>
				</FooterToolbar>
			)}

			<CreateForm
				onFinish={async (value) => {
					let success = false;
					if (value.id) {
						success = await handleUpdate(value);
					} else {
						success = await handleAdd(value);
					}
					console.log('success', success);
					if (success) {
						handleModalVisible(false);
						setCurrentRow(undefined);
					}
					actionRef.current?.reload();
				}}
				onCancel={() => {
					handleModalVisible(false);
					setCurrentRow(undefined);
				}}
				createModalVisible={createModalVisible}
				values={currentRow || {}}
			/>

			{
				// 菜谱关联加盟商商品 弹窗
				currentRow && menuGoodsModal && <MenuGoods foodMenu={currentRow} open={menuGoodsModal} onOk={handleMenuGoodsOk} onCancel={() => setMenuGoodsModal(false)}></MenuGoods>
			}
		</PageContainer>
	);
};

export default GoodsTypeManage;
